@@ -87,12 +87,17 @@ app state variables
 
 This module is providing/pre-defining the following application state variables:
 
+    * :attr:`~MainAppBase.app_state_version`
     * :attr:`~MainAppBase.flow_id`
+    * :attr:`~MainAppBase.flow_id_ink`
     * :attr:`~MainAppBase.flow_path`
+    * :attr:`~MainAppBase.flow_path_ink`
     * :attr:`~MainAppBase.font_size`
     * :attr:`~MainAppBase.lang_code`
     * :attr:`~MainAppBase.light_theme`
+    * :attr:`~MainAppBase.selected_item_ink`
     * :attr:`~MainAppBase.sound_volume`
+    * :attr:`~MainAppBase.unselected_item_ink`
     * :attr:`~MainAppBase.vibration_volume`
     * :attr:`~MainAppBase.win_rectangle`
 
@@ -130,8 +135,8 @@ app state constants
 ^^^^^^^^^^^^^^^^^^^
 
 This module is also providing some pre-defined constants that can be optionally used in your application in relation
-to the app states data store and for the app state config variables :attr:`~MainAppBase.font_size` and
-:attr:`~MainAppBase.light_theme`:
+to the app states data store and for the app state config variables :attr:`~MainAppBase.app_state_version`,
+:attr:`~MainAppBase.font_size` and :attr:`~MainAppBase.light_theme`:
 
     * :data:`APP_STATE_SECTION_NAME`
     * :data:`APP_STATE_VERSION_VAR_NAME`
@@ -340,8 +345,16 @@ Most of the base implementation helper methods can be overwritten by either the
 by user main app class.
 
 
-base gui sound resources
-------------------------
+base resources for your gui app
+-------------------------------
+
+This portion is also providing base resources for commonly used images and sounds. Commonly used i18n translation texts
+are provided by the ae namespace portion :mod:`ae.gui_help`.
+
+The image file resources provided by this portion are taken from:
+
+* :ref:`iconmonstr <https://iconmonstr.com/interface/>`.
+
 
 The sound files provides by this portion are taken from:
 
@@ -357,17 +370,17 @@ from abc import ABC, abstractmethod
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type
 
-from ae.base import NAME_PARTS_SEP, now_str, snake_to_camel                             # type: ignore
+from ae.base import NAME_PARTS_SEP, duplicates, now_str, snake_to_camel  # type: ignore
 from ae.paths import Collector, norm_path, path_folders                                 # type: ignore
 from ae.updater import check_all                                                        # type: ignore
 from ae.inspector import stack_var                                                      # type: ignore
 from ae.files import FilesRegister, RegisteredFile                                      # type: ignore
 from ae.i18n import default_language, load_language_texts, register_translations_path   # type: ignore
-from ae.core import DEBUG_LEVELS                                                        # type: ignore
+from ae.core import DEBUG_LEVELS, registered_app_names                                  # type: ignore
 from ae.console import ConsoleApp                                                       # type: ignore
 
 
-__version__ = '0.1.58'
+__version__ = '0.1.60'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -598,13 +611,22 @@ class MainAppBase(ConsoleApp, ABC):
     """ abstract base class for to implement a GUIApp-conform app class """
     # app states
     app_state_version: int = 0                              #: version number of the app state variables in <config>.ini
+
     flow_id: str = ""                                       #: id of the current app flow (entered by the app user)
     flow_path: List[str]                                    #: list of flow ids, reflecting recent user actions
+    flow_id_ink: tuple = (0.99, 0.99, 0.69, 0.69)           #: rgba color for flow id / drag&drop node placeholder
+    flow_path_ink: tuple = (0.99, 0.99, 0.39, 0.48)         #: rgba color for flow_path/drag&drop item placeholder
+
     font_size: float = 21.0                                 #: font size used for toolbar and flow screens
     lang_code: str = ""                                     #: optional language code (e.g. 'es_ES' for Spanish)
     light_theme: bool = False                               #: True=light theme/background, False=dark theme
+
+    selected_item_ink: tuple = (0.69, 1.0, 0.39, 0.18)      #: rgba color for list items (selected)
+    unselected_item_ink: tuple = (0.39, 0.39, 0.39, 0.18)   #: rgba color for list items (unselected)
+
     sound_volume: float = 0.12                              #: sound volume of current app (0.0=mute, 1.0=max)
     vibration_volume: float = 0.3                           #: vibration volume of current app (0.0=mute, 1.0=max)
+
     win_rectangle: tuple = (0, 0, 800, 600)                 #: window coordinates (x, y, width, height)
 
     # optional generic run-time shortcut references
@@ -646,8 +668,6 @@ class MainAppBase(ConsoleApp, ABC):
                                         the GUI event loop.
         """
 
-    # app state helper methods
-
     def app_state_keys(self) -> Tuple[str, ...]:
         """ determine current config variable names/keys of the app state section :data:`APP_STATE_SECTION_NAME`.
 
@@ -665,16 +685,19 @@ class MainAppBase(ConsoleApp, ABC):
         backup_root = norm_path("{ado}") + now_str(sep="_")
         os.makedirs(backup_root)
 
+        copy_function = shutil.copy     # copy2 crashes on 'android' (see https://bugs.python.org/issue28141)
+
         coll = Collector()
-        coll.collect("{app}", "{usr}", "{cwd}", append=("*.ini", "*.cfg"))
+        app_configs = tuple(ana + "." + ext for ana in registered_app_names() for ext in ('ini', 'cfg'))
+        coll.collect("{ado}", "{usr}", "{cwd}", append=app_configs, only_first_of='prefix')
         for file in coll.files:
             if not os.path.exists(os.path.basename(file)):  # don't overwrite the first one found (the active one)
-                shutil.copy2(file, backup_root)
+                copy_function(file, backup_root)
 
         coll = Collector(path_scanner=path_folders)
         coll.collect("{ado}", "{cwd}", append=('img', 'loc', 'snd'), only_first_of='prefix')
         for path in coll.paths:
-            shutil.copytree(path, os.path.join(backup_root, os.path.basename(path)))
+            shutil.copytree(path, os.path.join(backup_root, os.path.basename(path)), copy_function=copy_function)
 
         return backup_root
 
@@ -706,188 +729,6 @@ class MainAppBase(ConsoleApp, ABC):
         if hasattr(self.framework_app, name):                   # has observable attribute duplicate
             setattr(self.framework_app, name, value)
 
-    def load_app_states(self):
-        """ load application state from the config files for to prepare app.run_app """
-        app_states = dict()
-        for key in self.app_state_keys():
-            app_states[key] = self.get_var(key, section=APP_STATE_SECTION_NAME)
-
-        self.setup_app_states(app_states)
-
-    # application events - declared in the order they get executed/fired
-
-    def on_app_init(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_init default/fallback event handler called")
-
-    def on_app_start(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_start default/fallback event handler called")
-
-    def on_app_run(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_run default/fallback event handler called")
-
-    def on_app_build(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_build default/fallback event handler called - loading app resources")
-
-        self.load_images()
-
-        self.load_sounds()
-
-        register_translations_path()
-        register_translations_path("{ado}")
-        self.load_translations(self.lang_code)
-
-    def on_app_stop(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_stop default/fallback event handler called")
-
-    def on_app_exit(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_exit default/fallback event handler called")
-
-    def on_app_quit(self):
-        """ default/fallback flow change confirmation event handler. """
-        self.vpo("MainAppBase.on_app_quit default/fallback event handler called")
-
-    def on_debug_level_change(self, level_name: str, _event_kwargs: EventKwargsType) -> bool:
-        """ debug level app state change flow change confirmation event handler.
-
-        :param level_name:      the new debug level name to be set (passed as flow key).
-        :param _event_kwargs:   unused event kwargs.
-        :return:                True for to confirm the debug level change.
-        """
-        debug_level = next(num for num, name in DEBUG_LEVELS.items() if name == level_name)
-        self.vpo(f"MainAppBase.on_debug_level_change to {level_name} -> {debug_level}")
-        self.set_opt('debug_level', debug_level)
-        return True
-
-    def on_lang_code_change(self, lang_code: str, _event_kwargs: EventKwargsType) -> bool:
-        """ language app state change flow change confirmation event handler.
-
-        :param lang_code:       the new language code to be set (passed as flow key). Empty on first app run/start.
-        :param _event_kwargs:   unused event kwargs.
-        :return:                True for to confirm the language change.
-        """
-        self.vpo(f"MainAppBase.on_lang_code_change to {lang_code}")
-        self.load_translations(lang_code)
-        return True
-
-    def on_light_theme_change(self, _flow_key: str, event_kwargs: EventKwargsType) -> bool:
-        """ app theme app state change flow change confirmation event handler.
-
-        :param _flow_key:       flow key.
-        :param event_kwargs:    event kwargs with key `'light_theme'` containing True|False for light|dark theme.
-        :return:                True for to confirm change of flow id.
-        """
-        light_theme: bool = event_kwargs['light_theme']
-        self.vpo(f"MainAppBase.on_light_theme_change to {light_theme}")
-        self.change_app_state('light_theme', light_theme)
-        return True
-
-    def retrieve_app_states(self) -> AppStateType:
-        """ determine the state of a running app from the main app instance and return it as dict.
-
-        :return:                dict with all app states available in the config files.
-        """
-        app_state = dict()
-        for key in self.app_state_keys():
-            app_state[key] = getattr(self, key)
-
-        self.dpo(f"MainAppBase.retrieve_app_states {app_state}")
-        return app_state
-
-    def save_app_states(self) -> str:
-        """ save app state in config file.
-
-        :return:                empty string if app status could be saved into config files else error message.
-        """
-        err_msg = ""
-
-        app_state = self.retrieve_app_states()
-
-        for key, state in app_state.items():
-            if isinstance(state, (list, dict)):
-                state = deepcopy(state)
-
-            new_state = self.call_method(f'on_app_state_{key}_save', state)
-            if new_state is not None:
-                state = new_state
-
-            if key == 'flow_id' and flow_action(state) != 'focus':
-                state = id_of_flow('')
-            elif key == 'flow_path':
-                state = [flow_id for flow_id in state if flow_action(flow_id) == 'enter']
-
-            err_msg = self.set_var(key, state, section=APP_STATE_SECTION_NAME)
-            self.vpo(f"MainAppBase.save_app_state {key}={state} {err_msg or 'OK'}")
-            if err_msg:
-                break
-        self.load_cfg_files()
-
-        if self.debug_level:
-            self.play_sound('error' if err_msg else 'debug_save')
-        return err_msg
-
-    def setup_app_states(self, app_states: AppStateType):
-        """ put app state variables into main app instance for to prepare framework app.run_app.
-
-        :param app_states:      dict of app states.
-        """
-        self.vpo(f"MainAppBase.setup_app_states {app_states}")
-        for key, val in app_states.items():
-            self.change_app_state(key, val, send_event=False)   # don't send on_-events as framework is not initialized
-            if key == 'flow_id' and flow_action(val) == 'focus':
-                self._last_focus_flow_id = val
-
-        def upd_app_state(upd_key, upd_val, old_name=''):
-            """ update and optionally rename app state in app instance and config file. """
-            self.change_app_state(upd_key, upd_val, send_event=False)
-            self.set_var(upd_key, upd_val, section=APP_STATE_SECTION_NAME, old_name=old_name)
-
-        config_file_version = app_states.get(APP_STATE_VERSION_VAR_NAME, 0)
-        for version in range(config_file_version, APP_STATE_CURRENT_VERSION):
-            if version == 0:
-                upd_app_state('light_theme', True)
-            elif version == 1:
-                upd_app_state('sound_volume', 0.96)
-            elif version == 2:
-                if 'context_id' not in app_states:
-                    continue    # update - only needed for LiszApp apps
-
-                def mig_node(parent_node):
-                    """ recursively migrate sub_list to node key. """
-                    new_parent_node = list()
-                    for item in parent_node:
-                        node = item.pop('sub_list', None)
-                        if node is not None:
-                            item['node'] = mig_node(node)
-                        new_parent_node.append(item)
-                    return new_parent_node
-                upd_app_state('root_node', mig_node(app_states['data_tree']), 'data_tree')
-                upd_app_state('flow_path_ink', app_states['context_path_ink'], 'context_path_ink')
-                upd_app_state('flow_id_ink', app_states['context_id_ink'], 'context_id_ink')
-                upd_app_state('flow_path', [], 'context_path')
-                upd_app_state('flow_id', '', 'context_id')
-
-        if config_file_version < APP_STATE_CURRENT_VERSION:
-            upd_app_state(APP_STATE_VERSION_VAR_NAME, APP_STATE_CURRENT_VERSION)
-
-    # flow helper methods
-
-    @staticmethod
-    def class_by_name(class_name: str) -> Optional[Type]:
-        """ search class name in framework modules as well as in app main.py for to return class object.
-
-        dirty fallback using the inspect module - implemented as method for to allow overwrite in your app project.
-
-        :param class_name:      name of the class.
-        :return:                class object with the specified class name or None if not found.
-        """
-        return stack_var(class_name)
-
     def change_flow(self, new_flow_id: str, **event_kwargs) -> bool:
         """ try to change/switch the current flow id to the value passed in :paramref:`~change_flow.new_flow_id`.
 
@@ -999,62 +840,21 @@ class MainAppBase(ConsoleApp, ABC):
 
         return True
 
-    def flow_path_action(self, flow_path: Optional[List[str]] = None, path_index: int = -1) -> str:
-        """ determine the action of the last/newest entry in the flow_path.
+    @staticmethod
+    def class_by_name(class_name: str) -> Optional[Type]:
+        """ search class name in framework modules as well as in app main.py for to return class object.
 
-        :param flow_path:       flow path to get the flow action from (default=self.flow_path).
-        :param path_index:      index in the flow_path.
-        :return:                flow action string or empty string if index does not exist.
+        dirty fallback using the inspect module - implemented as method for to allow overwrite in your app project.
+
+        :param class_name:      name of the class.
+        :return:                class object with the specified class name or None if not found.
         """
-        if flow_path is None:
-            flow_path = self.flow_path
-        if len(flow_path) >= (abs(path_index) if path_index < 0 else path_index + 1):
-            return flow_action(flow_path[path_index])
-        return ''
-
-    def flow_path_strip(self, flow_path: List[str]) -> List[str]:
-        """ return flow_path copy with all non-enter actions stripped from the end.
-
-        :param flow_path:       flow path list to strip.
-        :return:                stripped flow path copy.
-        """
-        deep = len(flow_path)
-        while deep and self.flow_path_action(flow_path=flow_path, path_index=deep - 1) != 'enter':
-            deep -= 1
-        return flow_path[:deep]
-
-    def on_flow_change(self, flow_id: str, event_kwargs: EventKwargsType) -> bool:
-        """ checking if exists a Popup class for the new flow and if yes then open it.
-
-        :param flow_id:         new flow id.
-        :param event_kwargs:    optional event kwargs; the optional item with the key `popup_kwargs`
-                                will be passed onto the `__init__` method of the found Popup class.
-        :return:                True if Popup class was found and displayed.
-
-        This method is mainly used as the last fallback clicked flow change confirmation event handler of a FlowButton.
-        """
-        class_name = flow_popup_class_name(flow_id)
-        self.vpo(f"MainAppBase.on_flow_change '{flow_id}' {event_kwargs} lookup={class_name}")
-
-        if flow_id:
-            popup_class = self.class_by_name(class_name)
-            if popup_class:
-                popup_kwargs = event_kwargs.get('popup_kwargs', dict())
-                self.show_popup(popup_class, **popup_kwargs)
-                return True
-        return False
+        return stack_var(class_name)
 
     @staticmethod
-    def on_flow_popup_close(_flow_key: str, _popup_args: EventKwargsType) -> bool:
-        """ default popup close handler of FlowPopup widget, ensuring update of :attr:`flow_path`.
-
-        :param _flow_key:       unused flow key.
-        :param _popup_args:     unused popup args.
-        :return:                always returning True.
-        """
-        return True
-
-    # other helper methods and default event handlers
+    def dpi_factor() -> float:
+        """ dpi scaling factor - overwrite if the used GUI framework supports dpi scaling. """
+        return 1.0
 
     def find_image(self, image_name: str, height: float = 32.0, light_theme: bool = True) -> Optional[RegisteredFile]:
         """ find best fitting image in img app folder (see also :meth:`~MainAppBase.img_file` for easier usage).
@@ -1094,6 +894,30 @@ class MainAppBase(ConsoleApp, ABC):
             return self.sound_files(sound_name)
         return None
 
+    def flow_path_action(self, flow_path: Optional[List[str]] = None, path_index: int = -1) -> str:
+        """ determine the action of the last/newest entry in the flow_path.
+
+        :param flow_path:       flow path to get the flow action from (default=self.flow_path).
+        :param path_index:      index in the flow_path.
+        :return:                flow action string or empty string if index does not exist.
+        """
+        if flow_path is None:
+            flow_path = self.flow_path
+        if len(flow_path) >= (abs(path_index) if path_index < 0 else path_index + 1):
+            return flow_action(flow_path[path_index])
+        return ''
+
+    def flow_path_strip(self, flow_path: List[str]) -> List[str]:
+        """ return flow_path copy with all non-enter actions stripped from the end.
+
+        :param flow_path:       flow path list to strip.
+        :return:                stripped flow path copy.
+        """
+        deep = len(flow_path)
+        while deep and self.flow_path_action(flow_path=flow_path, path_index=deep - 1) != 'enter':
+            deep -= 1
+        return flow_path[:deep]
+
     def img_file(self, image_name: str, font_size: Optional[float] = None, light_theme: Optional[bool] = None) -> str:
         """ shortcutting :meth:`~MainAppBase.find_image` method w/o bound property for to get image file path.
 
@@ -1129,6 +953,20 @@ class MainAppBase(ConsoleApp, ABC):
         # call default handler; pass lower key code (enaml/Qt sends upper-case key code if Shift modifier is pressed)
         return self.call_method('on_key_press', modifiers, key.lower()) or False
 
+    def load_app_states(self):
+        """ load application state from the config files for to prepare app.run_app """
+        app_states = dict()
+        for key in self.app_state_keys():
+            app_states[key] = self.get_var(key, section=APP_STATE_SECTION_NAME)
+            if self.debug:
+                pre = f"   *  app state '{key}' "
+                if not hasattr(self, key):
+                    self.dpo(f"{pre}is not declared as MainAppBase attribute")
+                elif not isinstance(app_states[key], type(getattr(self, key))):
+                    self.dpo(f"{pre}type mismatch: attr={type(getattr(self, key))} config-var={type(app_states[key])}")
+
+        self.setup_app_states(app_states)
+
     def load_images(self):
         """ load images from app folder img. """
         file_reg = FilesRegister()
@@ -1137,6 +975,12 @@ class MainAppBase(ConsoleApp, ABC):
         file_reg.add_paths('{ado}/img/**')
         self.image_files = file_reg
 
+        if self.debug:
+            for name, files in file_reg.items():
+                dup_files = duplicates(os.path.abspath(os.path.normpath(str(file))) for file in files)
+                if dup_files:   # pragma: no cover
+                    self.dpo(f"   *  MainAppBase.load_images: duplicate image file paths for '{name}': {dup_files}")
+
     def load_sounds(self):
         """ load audio sounds from app folder snd. """
         file_reg = FilesRegister()
@@ -1145,6 +989,12 @@ class MainAppBase(ConsoleApp, ABC):
         file_reg.add_paths('{ado}/snd/**')
         self.sound_files = file_reg
 
+        if self.debug:
+            for name, files in file_reg.items():
+                dup_files = duplicates(os.path.abspath(os.path.normpath(str(file))) for file in files)
+                if dup_files:       # pragma: no cover
+                    self.dpo(f"   *  MainAppBase.load_sounds: duplicate sound file paths for '{name}': {dup_files}")
+
     def load_translations(self, lang_code: str):
         """ load translation texts for the passed language code.
 
@@ -1160,6 +1010,108 @@ class MainAppBase(ConsoleApp, ABC):
             default_language(lang_code)
             self.set_var('lang_code', lang_code, section=APP_STATE_SECTION_NAME)  # add optional app state var to config
 
+    def on_app_build(self):
+        """ default/fallback flow change confirmation event handler. """
+        self.vpo("MainAppBase.on_app_build default/fallback event handler called - loading app resources")
+
+        self.load_images()
+
+        self.load_sounds()
+
+        register_translations_path()
+        register_translations_path("{ado}")
+        self.load_translations(self.lang_code)
+
+    def on_app_exit(self):
+        """ default/fallback flow change confirmation event handler. """
+        self.vpo("MainAppBase.on_app_exit default/fallback event handler called")
+
+    def on_app_init(self):
+        """ default/fallback flow change confirmation event handler. """
+        self.vpo("MainAppBase.on_app_init default/fallback event handler called")
+
+    def on_app_quit(self):
+        """ default/fallback flow change confirmation event handler. """
+        self.vpo("MainAppBase.on_app_quit default/fallback event handler called")
+
+    def on_app_run(self):
+        """ default/fallback flow change confirmation event handler. """
+        self.vpo("MainAppBase.on_app_run default/fallback event handler called")
+
+    def on_app_start(self):
+        """ default/fallback flow change confirmation event handler. """
+        self.vpo("MainAppBase.on_app_start default/fallback event handler called")
+
+    def on_app_stop(self):
+        """ default/fallback flow change confirmation event handler. """
+        self.vpo("MainAppBase.on_app_stop default/fallback event handler called")
+
+    def on_debug_level_change(self, level_name: str, _event_kwargs: EventKwargsType) -> bool:
+        """ debug level app state change flow change confirmation event handler.
+
+        :param level_name:      the new debug level name to be set (passed as flow key).
+        :param _event_kwargs:   unused event kwargs.
+        :return:                True for to confirm the debug level change.
+        """
+        debug_level = next(num for num, name in DEBUG_LEVELS.items() if name == level_name)
+        self.vpo(f"MainAppBase.on_debug_level_change to {level_name} -> {debug_level}")
+        self.set_opt('debug_level', debug_level)
+        return True
+
+    def on_flow_change(self, flow_id: str, event_kwargs: EventKwargsType) -> bool:
+        """ checking if exists a Popup class for the new flow and if yes then open it.
+
+        :param flow_id:         new flow id.
+        :param event_kwargs:    optional event kwargs; the optional item with the key `popup_kwargs`
+                                will be passed onto the `__init__` method of the found Popup class.
+        :return:                True if Popup class was found and displayed.
+
+        This method is mainly used as the last fallback clicked flow change confirmation event handler of a FlowButton.
+        """
+        class_name = flow_popup_class_name(flow_id)
+        self.vpo(f"MainAppBase.on_flow_change '{flow_id}' {event_kwargs} lookup={class_name}")
+
+        if flow_id:
+            popup_class = self.class_by_name(class_name)
+            if popup_class:
+                popup_kwargs = event_kwargs.get('popup_kwargs', dict())
+                self.show_popup(popup_class, **popup_kwargs)
+                return True
+        return False
+
+    @staticmethod
+    def on_flow_popup_close(_flow_key: str, _popup_args: EventKwargsType) -> bool:
+        """ default popup close handler of FlowPopup widget, ensuring update of :attr:`flow_path`.
+
+        :param _flow_key:       unused flow key.
+        :param _popup_args:     unused popup args.
+        :return:                always returning True.
+        """
+        return True
+
+    def on_lang_code_change(self, lang_code: str, _event_kwargs: EventKwargsType) -> bool:
+        """ language app state change flow change confirmation event handler.
+
+        :param lang_code:       the new language code to be set (passed as flow key). Empty on first app run/start.
+        :param _event_kwargs:   unused event kwargs.
+        :return:                True for to confirm the language change.
+        """
+        self.vpo(f"MainAppBase.on_lang_code_change to {lang_code}")
+        self.load_translations(lang_code)
+        return True
+
+    def on_light_theme_change(self, _flow_key: str, event_kwargs: EventKwargsType) -> bool:
+        """ app theme app state change flow change confirmation event handler.
+
+        :param _flow_key:       flow key.
+        :param event_kwargs:    event kwargs with key `'light_theme'` containing True|False for light|dark theme.
+        :return:                True for to confirm change of flow id.
+        """
+        light_theme: bool = event_kwargs['light_theme']
+        self.vpo(f"MainAppBase.on_light_theme_change to {light_theme}")
+        self.change_app_state('light_theme', light_theme)
+        return True
+
     def play_beep(self):
         """ make a short beep sound, should be overwritten by GUI framework. """
         self.po(chr(7), "MainAppBase.BEEP")
@@ -1178,6 +1130,18 @@ class MainAppBase(ConsoleApp, ABC):
         """
         self.po(f"MainAppBase.play_vibrate {pattern}")
 
+    def retrieve_app_states(self) -> AppStateType:
+        """ determine the state of a running app from the main app instance and return it as dict.
+
+        :return:                dict with all app states available in the config files.
+        """
+        app_state = dict()
+        for key in self.app_state_keys():
+            app_state[key] = getattr(self, key)
+
+        self.dpo(f"MainAppBase.retrieve_app_states {app_state}")
+        return app_state
+
     def run_app(self):
         """ startup main and framework applications. """
         self.dpo("MainAppBase.run_app")
@@ -1195,6 +1159,89 @@ class MainAppBase(ConsoleApp, ABC):
                 self.call_method('on_app_quit')
                 self.shutdown(self._exit_code or None)  # don't call sys.exit() for zero exit code
 
+    def save_app_states(self) -> str:
+        """ save app state in config file.
+
+        :return:                empty string if app status could be saved into config files else error message.
+        """
+        err_msg = ""
+
+        app_state = self.retrieve_app_states()
+
+        for key, state in app_state.items():
+            if isinstance(state, (list, dict)):
+                state = deepcopy(state)
+
+            new_state = self.call_method(f'on_app_state_{key}_save', state)
+            if new_state is not None:
+                state = new_state
+
+            if key == 'flow_id' and flow_action(state) != 'focus':
+                state = id_of_flow('')
+            elif key == 'flow_path':
+                state = [flow_id for flow_id in state if flow_action(flow_id) == 'enter']
+
+            err_msg = self.set_var(key, state, section=APP_STATE_SECTION_NAME)
+            self.vpo(f"MainAppBase.save_app_state {key}={state} {err_msg or 'OK'}")
+            if err_msg:
+                break
+        self.load_cfg_files()
+
+        if self.debug_level:
+            self.play_sound('error' if err_msg else 'debug_save')
+        return err_msg
+
+    def setup_app_states(self, app_states: AppStateType):
+        """ put app state variables into main app instance for to prepare framework app.run_app.
+
+        :param app_states:      dict of app states.
+        """
+        self.vpo(f"MainAppBase.setup_app_states {app_states}")
+
+        font_size = app_states.get('font_size', 0)
+        if not MIN_FONT_SIZE <= font_size <= MAX_FONT_SIZE:
+            if font_size < 0:
+                font_size = self.dpi_factor() * -font_size      # adopt device scaling on very first app start
+            app_states['font_size'] = min(max(MIN_FONT_SIZE, font_size), MAX_FONT_SIZE)
+
+        for key, val in app_states.items():
+            self.change_app_state(key, val, send_event=False)   # don't send on_-events as framework is not initialized
+            if key == 'flow_id' and flow_action(val) == 'focus':
+                self._last_focus_flow_id = val
+
+        def upd_app_state(upd_key, upd_val, old_name=''):
+            """ update and optionally rename app state in app instance and config file. """
+            self.change_app_state(upd_key, upd_val, send_event=False)
+            self.set_var(upd_key, upd_val, section=APP_STATE_SECTION_NAME, old_name=old_name)
+
+        config_file_version = app_states.get(APP_STATE_VERSION_VAR_NAME, 0)
+        for version in range(config_file_version, APP_STATE_CURRENT_VERSION):
+            if version == 0:
+                upd_app_state('light_theme', True)
+            elif version == 1:
+                upd_app_state('sound_volume', 0.96)
+            elif version == 2:
+                if 'context_id' not in app_states:
+                    continue    # update - only needed for LiszApp apps
+
+                def mig_node(parent_node):
+                    """ recursively migrate sub_list to node key. """
+                    new_parent_node = list()
+                    for item in parent_node:
+                        node = item.pop('sub_list', None)
+                        if node is not None:
+                            item['node'] = mig_node(node)
+                        new_parent_node.append(item)
+                    return new_parent_node
+                upd_app_state('root_node', mig_node(app_states['data_tree']), 'data_tree')
+                upd_app_state('flow_path_ink', app_states['context_path_ink'], 'context_path_ink')
+                upd_app_state('flow_id_ink', app_states['context_id_ink'], 'context_id_ink')
+                upd_app_state('flow_path', [], 'context_path')
+                upd_app_state('flow_id', '', 'context_id')
+
+        if config_file_version < APP_STATE_CURRENT_VERSION:
+            upd_app_state(APP_STATE_VERSION_VAR_NAME, APP_STATE_CURRENT_VERSION)
+
     def show_popup(self, popup_class: Type, **popup_kwargs) -> Any:
         """ open Popup or DropDown by calling `show` method of passed instance.
 
